InvalidCommitReason

Enum InvalidCommitReason 

#[non_exhaustive]
pub enum InvalidCommitReason { NonMergeCommit, OctopusMerge, NotRelated, NotACommit, InvalidSubject(String), MissingId, MissingUrl, ZeroId, UnparseableId(String), }
Why a commit is not a valid staging branch commit.

The staging branch format is such that its first-parent history consists solely of two-parent merge commits. It must also have the base commit as an ancestor.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


NonMergeCommit

A non-merge commit was found.



OctopusMerge

An octopus merge commit was found.



NotRelated

The integration branch is not related to the base.



NotACommit

The integration branch does not point to a commit.



InvalidSubject(String)

A merge commit has an invalid commit subject.



MissingId

A merge commit is missing an ID.



MissingUrl

A merge commit is missing a URL.



ZeroId

A topic has in ID of 0, which is reserved for the base branch.



UnparseableId(String)

A topic has in ID that is not an unsigned integer.